@@ -31,7 +31,7 @@ impl Error {
         let msg: Cow<_> = match &self.inner.1 {
             ErrorKind::Eof => "Unexpected end of file".into(),
             ErrorKind::Ignore => "Not an error".into(),
-            ErrorKind::UnexpectedChar(c) => format!("Unexpected charcter `{:?}`", c).into(),
+            ErrorKind::UnexpectedChar(c) => format!("Unexpected character `{:?}`", c).into(),
             ErrorKind::UnterminatedUrl => "Unterminated url literal".into(),
             ErrorKind::InvalidEscape => "Invalid escape".into(),
             ErrorKind::Expected(s) => format!("Expected {}", s).into(),
@@ -71,7 +71,7 @@ pub enum ErrorKind {
     Eof,
     Ignore,
     /// Lexing error.
-    UnexpectedChar(Option<char>),
+    UnexpectedChar(char),
     /// Lexing error.
     UnterminatedUrl,
     /// Lexing error
